Digi XBee Python library
========================

This project is a version of the XBee Python library, an
easy-to-use API developed in Python that allows you to interact with Digi
International's `XBee <https://www.digi.com/xbee>`_ radio frequency (RF)
modules. It has been edited to be compatible with Python 2.

This source has been contributed by Digi International, with modifications by Tiana Ton Nu.


Installation
------------

You can install this version of the XBee Python library using `pip
<https://pip.pypa.io/en/stable/>`_::

    $ pip install ngcp-xbee


Install from Source
-------------------

You can install XBee Python library directly from the source file. To do
so, extract the source code to your computer and, from its root
directory, execute the following command::

    $ python setup.py install


Documentation
-------------

XBee Python library has user guide and API reference documentation hosted on
Read the Docs. You can find the latest, most up to date, documentation at
`latest docs <https://xbplib.readthedocs.io/en/latest>`_. To see only those
features which have been released, check out the
`stable docs <https://xbplib.readthedocs.io/en/stable>`_.


How to contribute
-----------------

The contributing guidelines are in the `CONTRIBUTING.rst document
<https://github.com/digidotcom/python-xbee/blob/master/CONTRIBUTING.rst>`_.


License
-------

Copyright 2017, Digi International Inc.

The `MPL 2.0 license <https://github.com/digidotcom/python-xbee/blob/master/LICENSE.txt>`_
covers the majority of this project with the following exceptions:

* The `ISC license <https://github.com/digidotcom/python-xbee/blob/master/examples/LICENSE.txt>`_
  covers the contents of the examples directory.
